@@ -213,6 +213,32 @@ _unur_dgt_sample( struct unur_gen *gen )
   return (j + DISTR.domain[0]);
 } 
 int
+unur_dgt_eval_invcdf( const struct unur_gen *gen, double u )
+{
+  int j;
+  _unur_check_NULL( GENTYPE, gen, INT_MAX );
+  if ( gen->method != UNUR_METH_DGT ) {
+    _unur_error(gen->genid,UNUR_ERR_GEN_INVALID,"");
+    return INT_MAX;
+  }
+  COOKIE_CHECK(gen,CK_DGT_GEN,INT_MAX);
+  if ( ! (u>0. && u<1.)) {
+    if ( ! (u>=0. && u<=1.)) {
+      _unur_warning(gen->genid,UNUR_ERR_DOMAIN,"U not in [0,1]");
+    }
+    if (u<=0.) return DISTR.domain[0];
+    if (u>=1.) return DISTR.domain[1];
+    return INT_MAX;  
+  }
+  j = GEN->guide_table[(int)(u * GEN->guide_size)];
+  u *= GEN->sum;
+  while (GEN->cumpv[j] < u) j++;
+  j+=DISTR.domain[0];
+  if (j<DISTR.domain[0]) j = DISTR.domain[0];
+  if (j>DISTR.domain[1]) j = DISTR.domain[1];
+  return j;
+} 
+int
 _unur_dgt_create_tables( struct unur_gen *gen )
 { 
   GEN->guide_size = (int)( DISTR.n_pv * GEN->guide_factor);
