@@ -449,11 +449,10 @@ unur_hinv_eval_approxinvcdf( const struct unur_gen *gen, double u )
 int
 unur_hinv_estimate_error( const UNUR_GEN *gen, int samplesize, double *max_error, double *MAE )
 { 
-  double score;
   _unur_check_NULL(GENTYPE, gen, UNUR_ERR_NULL);  
   COOKIE_CHECK(gen,CK_HINV_GEN,UNUR_ERR_COOKIE);
-  score = unur_test_inverror(gen, max_error, MAE, 1.e-20, samplesize, 
-			     FALSE, FALSE, FALSE, NULL);
+  unur_test_inverror(gen, max_error, MAE, 1.e-20, samplesize, 
+		     FALSE, FALSE, FALSE, NULL);
   return UNUR_SUCCESS;
 } 
 int
